      SUBROUTINE bgcflx
#if defined key_top
!!!---------------------------------------------------------------------
!!!
!!!                       ROUTINE bgcflx
!!!                     ******************
!!!
!!!
!!     PURPOSE.
!!     --------
!!          calculates gas exchange and chemistry at sea surface 
!!
!!     METHOD.
!!     -------
!!          solving system of two non-linear simultaneous equations for [H2CO3]i
!!          and [H+] 
!!
!!     EXTERNALS.
!!     ----------
!!          none.
!!
!!     REFERENCE.
!!     ----------
!!
!!          Broecker, W.S., and T.-H. Pend (1982) Tracers in the sea.
!!          Eldigio press, Lamont-Doherty Geological Observatory,
!!          Palisades, N.Y., 690 PP..
!!
!!          Mook, W.G. (1986), 13C in atmospheric CO2.
!!          Netherlands Journal of Sea Research, 20(2/3): 211-223.
!!
!!          Scarborough, J. (1958) Numerical Mathematical Analysis.
!!          Oxford Univertiry Press, London, 4TH ED., 576 PP..
!!
!!      VARIABLE           TYPE    PURPOSE.
!!      --------           ----    --------
!!
!!      alka              REAL    actual [ALK] [EQV/L]
!!      akb               REAL    1. dissoc. constant of boric acid
!!      h2co3(jpi,jpj)    REAL    surface [H2CO3] [MOLE/L]
!!      krorr          INTEGER    counts iterations in Newton-Raphson algorithm
!!      ct1               REAL    actual valua of inorg. C
!!      x1                REAL    [H+] expressed as sqrt(AK1*AK2)/[H+]
!!      zpa               REAL    atmospheric pco2 [ppm]
!!      fld               REAL    [CO2] flux atmosphere -> ocean in [mol/m2/s]
!!      flu               REAL    [CO2] flux ocean -> atmosphere in [mol/m2/s]
!!      relw13            REAL    ratio [sum((13C)O2)]/[sum((12C)O2)] in surface layer
!!      rela13            REAL    ratio [sum((13C)O2)]/[sum((12C)O2)] in the atmosphere
!!
!!   MODIFICATIONS:
!!   --------------
!!      original      : 1988-07 E. Maier-Reimer
!!      additions     : 1998    O. Aumont
!!      modifications : 1999    C. Le Quere
!!      modifications : 2004    C. Le Quere
!!     -----------------------------------------------------------------
!!  parameters and commons
!! ======================
      USE trc
      USE trp_trc
      USE sms
      USE oce_trc
      IMPLICIT NONE
!!----------------------------------------------------------------------
!! local declarations
!! ==================
!
!
      INTEGER ji, jj
      REAL ttc, ws, krorr
      REAL ttcdms
      REAL za, zpa, zvapor, ztkel, fld, flu
      REAL oxy16, flu16
      REAL zph,ah2,bot
      REAL ct1,alka
      REAL zkgco2(jpi,jpj),zkgo2(jpi,jpj)
      REAL schmico2, schmio2
      REAL schmidms,fludms,zkgdms(jpi,jpj)
      REAL schmin2o,flun2a,flun2b,flun2c,flun2d,flun2e,flun2n,flun2o,flun2s,zkgn2o(jpi,jpj)
#  include "domzgr_substitute.h90"
!
! surface chemistry (pCO2 AND [H+] in surface layer)
! --------------------------------------------------
!
      DO krorr = 1, 15
!
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
!
! total borate
! ------------
!
            bot  = chemc(ji,jj,2)
            ct1  = trn(ji,jj,1,jpdic)
            alka = trn(ji,jj,1,jptal)
            zph  = amax1(hi(ji,jj,1),1.E-10)
!
! calculate [alk]([CO3--], [HCO3-])
! ---------------------------------
!
            za = alka- &
     &          (akw3(ji,jj,1)/zph-zph+bot/(1.+zph/akb3(ji,jj,1)))
!
! calculate [H+] AND [H2CO3]
! --------------------------
!
            ah2 = sqrt((ct1-za)**2+4*(za*ak23(ji,jj,1)/ak13(ji,jj,1)) &
     &           * (2*ct1-za)) 
            ah2 = 0.5*ak13(ji,jj,1)/za*((ct1-za)+ah2)
            hi(ji,jj,1)  = ah2
            h2co3(ji,jj) = (2*ct1-za)/(2.+ak13(ji,jj,1)/ah2)
!
          END DO
        END DO
      END DO
!
! compute fluxes
! --------------
!
! first compute gas exchange coefficients
! ---------------------------------------
!
      DO jj = 2, nlcj-1
        DO ji = 2, nlci-1
!
          ttc      = min(39.,tn(ji,jj,1))
          ttcdms   = min(36.,tn(ji,jj,1))
!
! use wind speed in m/s
! ---------------------
!
          ws = wndm(ji,jj)
!
! this is Wanninkhof (1992) equation 8 (with chemical enhancement), in cm/h
! -------------------------------------------------------------------------
!
          kgwanin(ji,jj) = (0.3*ws*ws + 2.5*(0.5246+ttc*(0.016256+ &
     &        ttc*0.00049946)))
!
! convert from cm/h to m/s and apply ice cover
! --------------------------------------------
!
          kgwanin(ji,jj) = kgwanin(ji,jj) /100./3600.  &
     &                   * (1-fr_i(ji,jj))
!
! compute Schmitt number for CO2 (Wanninkhof 1992)
! ------------------------------------------------
!
          schmico2 = 2073.1-125.62*ttc+3.6276*ttc**2-0.043126*ttc**3
          zkgco2(ji,jj) = kgwanin(ji,jj)*sqrt(660./schmico2)
!
! this is Wanninkhof (1992) equation 3 (steady winds)
!
          kgwanin(ji,jj) = 0.31*ws*ws
          kgwanin(ji,jj) = kgwanin(ji,jj) /100./3600.  &
     &                   * (1-fr_i(ji,jj))
!
! compute Schmitt number for O2 (Wanninkhof 1992)
! -----------------------------------------------
!
          schmio2 = 1953.4-128.0*ttc+3.9918*ttc**2-0.050091*ttc**3
          zkgo2(ji,jj) = kgwanin(ji,jj)*sqrt(660./schmio2)
! compute Schmitt number for DMS (Wanninkhof 1992)
!-------------------------------------------------

          schmidms = 3628.5-234.58*ttcdms+7.8601*ttcdms**2 &
                                 -0.1148*ttcdms**3
          zkgdms(ji,jj) = kgwanin(ji,jj)*sqrt(660./schmidms)
!
! compute Schmitt number for N2O (Wanninkhof 1992)
! -----------------------------------------------
!
           schmin2o = 2301.1-151.1*ttc+4.7364*ttc**2-0.059431*ttc**3
           zkgn2o(ji,jj) = kgwanin(ji,jj)*sqrt(660./schmin2o)
! correct atmospheric CO2 (pco2at in ppm) for 100% water vapor 
! following Sarmiento et al., JGR 1992
! ------------------------------------------------------------
!
           ztkel   = tn(ji,jj,1)+temzer
           zvapor = exp( 20.1050 - 0.0097982 * ztkel - 6163.10/ztkel)
           zpa = pco2at * (1. - zvapor)
!
! compute CO2 flux for the sea and air, 
! fld and flu are in mol/m2/s
! ---------------------------------------------
!
           fld = zpa*chemc(ji,jj,1)*1.e3*zkgco2(ji,jj)*tmask(ji,jj,1)
           flu = h2co3(ji,jj)      *1.e3*zkgco2(ji,jj)*tmask(ji,jj,1)
!
! add tendency in mol/L/s
! -----------------------
!
           tra(ji,jj,1,jpdic)= tra(ji,jj,1,jpdic)+(fld-flu)/1000./fse3t(ji,jj,1)
!
! Calculate cumulative flux mol/timestep
!
           qcumul(1)=qcumul(1)+(fld-flu)*rfact*e1t(ji,jj) &
     &         *e2t(ji,jj)*tmask(ji,jj,1)
!
! Compute O2 flux 
! ---------------
!
!          oxy16 = trn(ji,jj,1,jpoxy)
!          flu16 = (atcox*chemc(ji,jj,3)*(1.-zvapor) - oxy16) &
!     &      * zkgo2(ji,jj) * tmask(ji,jj,1)
!          tra(ji,jj,1,jpoxy) = tra(ji,jj,1,jpoxy)+flu16/fse3t(ji,jj,1)
!          qcumul(2)=qcumul(2)+flu16*rfact*e1t(ji,jj)*e2t(ji,jj)*tmask(ji,jj,1)
!
! add tendency in mol/L/s
! -----------------------
! Compute N2O flux
!
          flun2o = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -              &
     &      trn(ji,jj,1,jpn2o))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2o) = tra(ji,jj,1,jpn2o)+flun2o/fse3t(ji,jj,1)
          flun2s = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -              &
     &      trn(ji,jj,1,jpn2s))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2s) = tra(ji,jj,1,jpn2s)+flun2s/fse3t(ji,jj,1)
          flun2a = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -                 &
     &      trn(ji,jj,1,jpn2a))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2a) = tra(ji,jj,1,jpn2a)+flun2a/fse3t(ji,jj,1)
          flun2b = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -              &
     &      trn(ji,jj,1,jpn2b))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2b) = tra(ji,jj,1,jpn2b)+flun2b/fse3t(ji,jj,1)
          flun2c = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -                 &
     &      trn(ji,jj,1,jpn2c))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2c) = tra(ji,jj,1,jpn2c)+flun2c/fse3t(ji,jj,1)
          flun2d = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -                 &
     &      trn(ji,jj,1,jpn2d))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2d) = tra(ji,jj,1,jpn2d)+flun2d/fse3t(ji,jj,1)
          flun2e = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -                 &
     &      trn(ji,jj,1,jpn2e))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2e) = tra(ji,jj,1,jpn2e)+flun2e/fse3t(ji,jj,1)
          flun2n = (pn2oat*chemc(ji,jj,4)*(1.-zvapor) -              &
     &      trn(ji,jj,1,jpn2n))*zkgn2o(ji,jj)*tmask(ji,jj,1)
          tra(ji,jj,1,jpn2n) = tra(ji,jj,1,jpn2n)+flun2n/fse3t(ji,jj,1)
!
! Compute DMS flux
!
!          fludms = -trn(ji,jj,1,jpdms)*zkgdms(ji,jj)*tmask(ji,jj,1)
!          tra(ji,jj,1,jpdms) = tra(ji,jj,1,jpdms)+fludms/e3t_0(1)
!          if ( tra(ji,jj,1,jpdms) .gt. 1e21 .or. &
!             tra(ji,jj,1,jpdms) .le.-1e21 ) then
!            write(200,*) 'At ',ji,jj,tra(ji,jj,1,jpdms)
!           stop 'problem in bgcflx'
!          endif

!          qcumul(jpdms)=qcumul(jpdms)+fludms*1.e3*rfact*e1t(ji,jj)      &
!     &      *e2t(ji,jj)*tmask(ji,jj,1)
! Save diagnostics
! ----------------
!
#    if defined key_trc_diaadd
          trc2d(ji,jj,11) = trn(ji,jj,1,jpn2o)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,12) = trn(ji,jj,1,jpn2s)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,13) = trn(ji,jj,1,jpn2b)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,15) = trn(ji,jj,1,jpn2n)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,19) = trn(ji,jj,1,jpn2a)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,20) = trn(ji,jj,1,jpn2c)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,21) = trn(ji,jj,1,jpn2d)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,22) = trn(ji,jj,1,jpn2e)/chemc(ji,jj,4)-pn2oat
          trc2d(ji,jj,16) = fld-flu
          trc2d(ji,jj,27) = 0.!flu16*1000.
          trc2d(ji,jj,28) = h2co3(ji,jj)/chemc(ji,jj,1)
          trc2d(ji,jj,6) = flun2o*1000.
          trc2d(ji,jj,14) = flun2s*1000.
          trc2d(ji,jj,23) = flun2b*1000.
          trc2d(ji,jj,1) = flun2n*1000.
          trc2d(ji,jj,30) = flun2a*1000.
          trc2d(ji,jj,31) = flun2c*1000.
          trc2d(ji,jj,24) = flun2d*1000.
          trc2d(ji,jj,25) = flun2e*1000.
#    endif
        END DO
      END DO
#endif
      RETURN
      END

